<?php

namespace FiloBlu\Refilo\Model\Config\Seo;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Api\Data\StoreInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\Store;
use MageWorx\SeoBase\Helper\Data;

/**
 * Class HrefLangConfig
 * @package FiloBlu\Refilo\Model\Config\Seo
 */
class HrefLangConfig
{

    const REFILO_SEO_HREFLANG_ENABLED = 'mageworx_seo/base/hreflangs/enabled';
    const REFILO_SEO_HREFLANG_ENABLED_CATEGORY = 'mageworx_seo/base/hreflangs/enabled_category';
    const REFILO_SEO_HREFLANG_ENABLED_PRODUCT = 'mageworx_seo/base/hreflangs/enabled_product';
    const REFILO_SEO_HREFLANG_ENABLED_CMS = 'mageworx_seo/base/hreflangs/enabled_cms';
    const REFILO_SEO_HREFLANG_LANG_CODE = 'mageworx_seo/base/hreflangs/lang_code';
    const REFILO_SEO_HREFLANG_COUNTRY_CODE_ENABLED = 'mageworx_seo/base/hreflangs/country_code_enabled';
    const REFILO_SEO_HREFLANG_COUNTRY_CODE = 'mageworx_seo/base/hreflangs/country_code';
    const REFILO_SEO_HREFLANG_USE_MAGENTO_LANG_CODE = 'mageworx_seo/base/hreflangs/use_magento_lang_code';
    const REFILO_SEO_HREFLANG_ENABLED_HOME = 'refilo_content/general/enable_hreflang_home';
    const REFILO_SEO_CANONICAL_CANONICAL_STORE = 'mageworx_seo/base/canonical/cross_domain_store';
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * HrefLangConfig constructor.
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        ScopeConfigInterface $scopeConfig
    )
    {
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return string
     */
    public function getSeoLocaleCodeForStore($store): string
    {
        $locale = $this->scopeConfig->getValue(
            self::REFILO_SEO_HREFLANG_LANG_CODE,
            ScopeInterface::SCOPE_STORE,
            $store
        );

        if (empty($locale)) {
            $locale = $this->scopeConfig->getValue(self::REFILO_SEO_HREFLANG_LANG_CODE,
                ScopeInterface::SCOPE_STORE,
                0);
        }

        $addCountryCode = $this->scopeConfig->isSetFlag(
            self::REFILO_SEO_HREFLANG_COUNTRY_CODE_ENABLED,
            ScopeInterface::SCOPE_STORE,
            $store);

        if ($addCountryCode) {
            $locale .= '-' . $this->scopeConfig->getValue(
                    self::REFILO_SEO_HREFLANG_COUNTRY_CODE,
                    ScopeInterface::SCOPE_STORE,
                    $store);
        }
        return $locale;
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return array
     */
    public function getConfig($store): array
    {
        return [
            'enabled'               => $this->isHrefLangEnabled($store),
            'enabled_category'      => $this->isHrefLangEnabledForCategory($store),
            'enabled_product'       => $this->isHrefLangEnabledForProduct($store),
            'enabled_cms'           => $this->isHrefLangEnabledForCms($store),
            'enabled_home'          => $this->isHrefLangEnabledForHome($store),
            'use_magento_lang_code' => $this->getUseMagentoLangCode($store)
        ];
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function isHrefLangEnabled($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(self::REFILO_SEO_HREFLANG_ENABLED,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function isHrefLangEnabledForCategory($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(self::REFILO_SEO_HREFLANG_ENABLED_CATEGORY,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function isHrefLangEnabledForProduct($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(self::REFILO_SEO_HREFLANG_ENABLED_PRODUCT,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function isHrefLangEnabledForCms($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(self::REFILO_SEO_HREFLANG_ENABLED_CMS,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function isHrefLangEnabledForHome($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(self::REFILO_SEO_HREFLANG_ENABLED_HOME,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function getUseMagentoLangCode($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(self::REFILO_SEO_HREFLANG_USE_MAGENTO_LANG_CODE,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * @param int|string|StoreInterface|Store $store
     * @return bool
     */
    public function useCanonical($store = 0): bool
    {
        return $this->scopeConfig->isSetFlag(
            Data::XML_PATH_CANONICAL_URL_ENABLED,
            ScopeInterface::SCOPE_STORE,
            $store);
    }

    /**
     * Retrieve cross domain store ID
     *
     * @param int|string|StoreInterface|Store $store
     * @return int
     */
    public function getCanonicalStore($store): int
    {
        return (int)$this->scopeConfig->getValue(
            self::REFILO_SEO_CANONICAL_CANONICAL_STORE,
            ScopeInterface::SCOPE_STORE,
            $store
        );
    }

}
